//
//  MainViewController.m
//  MBMapDemo
//
//  Created by 张嘉伟 on 11-10-12.
//  Copyright (c) 2011年 __MyCompanyName__. All rights reserved.
//

#import "MainViewController.h"
#import "MapViewController.h"
#import "MapViewPanController.h"
#import "MapViewZoomController.h"
#import "MapViewAnnotationController.h"
#import "MapViewPolylineController.h"
#import "MapViewPolygonController.h"
#import "MapViewCircleController.h"
#import "SearchViewController.h"

@interface MainViewController()
-(void)addController:(UIViewController*)controller toSection:(NSString*)sectionName;
-(NSInteger)sectionCount;
-(NSInteger)sectionRowCount:(NSInteger)sectionIndex;
-(NSString*)sectionTitle:(NSInteger)sectionIndex;
-(UIViewController*)controllerAtIndexPath:(NSIndexPath*)path;
@end

@implementation MainViewController

-(void)addController:(UIViewController*)controller toSection:(NSString*)sectionName
{
	if(sections == nil)
	{
		sections = [[NSMutableDictionary alloc] init];
		sectionNames = [[NSMutableArray alloc] init];
	}
	NSMutableArray *list = [sections objectForKey:sectionName];
	if(list == nil)
	{
		list = [NSMutableArray array];
		[sections setValue:list forKey:sectionName];
		[sectionNames addObject:sectionName];
	}
	[list addObject:controller];
}

-(NSInteger)sectionCount
{
	return sections.count;
}

-(NSInteger)sectionRowCount:(NSInteger)sectionIndex;
{
	return [[sections objectForKey:[sectionNames objectAtIndex:sectionIndex]] count];
}

-(NSString*)sectionTitle:(NSInteger)sectionIndex
{
	return [sectionNames objectAtIndex:sectionIndex];
}

-(UIViewController*)controllerAtIndexPath:(NSIndexPath*)path
{
	return [[sections objectForKey:[sectionNames objectAtIndex:path.section]] objectAtIndex:path.row];
}

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)didReceiveMemoryWarning
{
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
}

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];

    self.title = @"图吧地图Demo";
    MapViewController *controller;
    
    MapView *mapView = [MapView sharedMapView];

    controller = [[MapViewController alloc] initWithMapView:mapView];
	controller.title = @"地图";
	controller.demoInfo = @"MapViewController";
	[self addController:controller toSection:@"初始化地图"];
	[controller release];
    
    controller = [[MapViewPanController alloc] initWithMapView:mapView];
	controller.title = @"移动地图";
	controller.demoInfo = @"MapViewPanController";
	[self addController:controller toSection:@"操作地图"];
	[controller release];
    
    controller = [[MapViewZoomController alloc] initWithMapView:mapView];
	controller.title = @"缩放地图";
	controller.demoInfo = @"MapViewZoomController";
	[self addController:controller toSection:@"操作地图"];
	[controller release];
    
    controller = [[MapViewAnnotationController alloc] initWithMapView:mapView];
	controller.title = @"标注地图";
	controller.demoInfo = @"MapViewAnnotationController";
	[self addController:controller toSection:@"标注"];
	[controller release];
    
    controller = [[MapViewPolylineController alloc] initWithMapView:mapView];
	controller.title = @"线条";
	controller.demoInfo = @"MapViewPolylineController";
	[self addController:controller toSection:@"绘制"];
	[controller release];

    controller = [[MapViewPolygonController alloc] initWithMapView:mapView];
	controller.title = @"多边形";
	controller.demoInfo = @"MapViewPolygonController";
	[self addController:controller toSection:@"绘制"];
	[controller release];
    
    controller = [[MapViewCircleController alloc] initWithMapView:mapView];
	controller.title = @"圆形";
	controller.demoInfo = @"MapViewCircleController";
	[self addController:controller toSection:@"绘制"];
	[controller release];
    
    UIViewController *searchController;
    searchController = [[SearchViewController alloc] init];
    searchController.title = @"搜索";
    [self addController:searchController toSection:@"服务"];
    // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
    // self.navigationItem.rightBarButtonItem = self.editButtonItem;
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (void)dealloc
{
	[sections release];
	[sectionNames release];
	[super dealloc];
}

#pragma mark UIViewController delegate

- (void)viewWillAppear:(BOOL)animated
{
	// this UIViewController is about to appear
	// make sure we remove the current selection from our table view
	NSIndexPath *tableSelection = [self.tableView indexPathForSelectedRow];
	[self.tableView deselectRowAtIndexPath:tableSelection animated:NO];
	// Set the navbar style to its default color for the list view.
	self.navigationController.navigationBar.barStyle = UIBarStyleDefault;
	// Set the status bar to its default color for the list view.
	[[UIApplication sharedApplication] setStatusBarStyle:UIStatusBarStyleDefault animated:YES];
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
}

- (void)viewDidDisappear:(BOOL)animated
{
    [super viewDidDisappear:animated];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

#pragma mark UITableView data source methods

// tell our table how many sections or groups it will have (always 1(our case)
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
	return [self sectionCount];
}

// tell our table how many rows it will have,(our case the size of our menuList
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
	return [self sectionRowCount:section];
}

-(NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section
{
	return [self sectionTitle:section];
}

// tell our table what kind of cell to use and its title for the given row
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
	UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"commonCell"];
	if (cell == nil)
	{
		cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:@"commonCell"] autorelease];
	}
	UIViewController *vc = [self controllerAtIndexPath:indexPath];
    if ([vc isKindOfClass:[MapViewController class]]) {
        MapViewController *controller = (MapViewController *)vc;
        cell.detailTextLabel.text = controller.demoInfo;
    }
	cell.textLabel.text = vc.title;
	cell.detailTextLabel.adjustsFontSizeToFitWidth = YES;
	cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
    
	return cell;
}

#pragma mark - Table view delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    UIViewController *targetViewController = [self controllerAtIndexPath:indexPath];
	[[self navigationController] pushViewController:targetViewController animated:YES];
}

@end
