//
//  MBBusResult.h
//  MBMapkit_library
//
//  Created by 张嘉伟 on 11-10-26.
//  Copyright 2011 Mapbar Inc. All rights reserved.
//


#import <Foundation/Foundation.h>
#import <CoreLocation/CoreLocation.h>

#import "MBListResult.h"

/** @interface MBBusStationResult
 *
 *  @brief
 *      MBBusStationResult对象表示返回公交站点的结果列表
 *      返回结果中的resultList为MBBusStation对象的数组包含了站点对应路线详细的searchString
 */
@interface MBBusStationResult : MBListResult

//
@end

/** @interface MBBusStation
 *
 *  @brief
 *      MBBusStation对象表示返回公交站点对象
 *   
 */
@interface MBBusStation : NSObject
{
@private
    NSDictionary *_internal;
    NSString *_name;
    NSUInteger _numLines;
    NSString *_address;
    CLLocationCoordinate2D _coordinate;
    NSString *_searchString;
}
/** @property   name
 *
 *  @brief  站点名称
 */
@property (nonatomic, readonly) NSString *name;

/** @property   address
 *
 *  @brief  地址
 */
@property (nonatomic, readonly) NSUInteger numLines;

/** @property   linesCount
 *
 *  @brief  站点包含线路条数
 */
@property (nonatomic, readonly) NSString *address;

/** @property   coordinate
 *
 *  @brief  经纬度
 */
@property (nonatomic, readonly) CLLocationCoordinate2D coordinate;

/** @property   more
 *
 *  @brief  更多 //&tp=7_8&q=天安门西&ct=北京市
 *  @note
 *          将more参数
 */
@property (nonatomic, readonly) NSString *searchString;

/** 
 *
 *  @brief 初始化MBBusStation对象
 *  @param dictionary 包含MBBusStation对象内容的数据字典
 *
 */
-(id)initWithDictionary:(NSDictionary *)dictionary;

@end

/** @interface MBBusStationDetailResult
 *
 *  @brief
 *      MBBusStation对象表示站点经过的线路的结果
 *   
 */
@interface MBBusStationDetailResult : NSObject {
@private
    NSDictionary *_internal;
    NSArray *_lines;
}

/** @property   lines
 *
 *  @brief  经过该站点的线路条数,MBBusStationDetail对象的数组
 */
@property (nonatomic, readonly) NSArray *lines;

/** 
 *
 *  @brief 初始化MBBusStationDetailResult对象
 *  @param dictionary 包含MBBusStationDetailResult对象内容的数据字典
 *
 */
-(id)initWithDictionary:(NSDictionary *)dictionary;

@end

/** @interface MBBusStationDetailResult
 *
 *  @brief
 *      MBBusStation对象表示经过该站点的线路信息
 *   
 */
@interface MBBusStationDetail : NSObject {
@private
    NSDictionary *_internal;
    NSString *_lineName;
    CLLocationCoordinate2D _coordinate;
    NSUInteger _lineType;
    NSString *_searchString;
}
/** @property   lineName
 *
 *  @brief  经过该站点的线路名称
 */
@property (nonatomic, readonly) NSString *lineName;

/** @property   coordinate
 *
 *  @brief  经过该站点在此线路中的坐标
 */
@property (nonatomic, readonly) CLLocationCoordinate2D coordinate;

/** @property   lineType
 *
 *  @brief  线路类型
 */
@property (nonatomic, readonly) NSUInteger lineType;

/** @property   searchString
 *
 *  @brief   更多 eg.&q=运通106路上行(田村北路-中央党校北门)&ct=北京市
 */
@property (nonatomic, readonly) NSString *searchString;

/** 
 *
 *  @brief 初始化MBBusStationDetailResult对象
 *  @param dictionary 包含MBBusStationDetailResult对象内容的数据字典
 *
 */
-(id)initWithDictionary:(NSDictionary *)dictionary;

@end

/** @interface MBBusLineResult
 *
 *  @brief
 *      MBBusLineResult对象表示返回根据关键字查询公交线路的结果列表
 *      返回结果中的resultList为MBBusLine对象的数组包含了站点对应路线详细的searchString
 *   
 */
@interface MBBusLineResult : MBListResult

@end

@interface MBBusLine : NSObject
{
@private
    NSDictionary *_internal;
    NSString *_name;
    NSString *_searchString;
}
/** @property   name
 *
 *  @brief  名称
 */
@property (nonatomic, readonly) NSString *name;
/**
 */
/** @property   searchString
 *
 *  @brief  搜索更详细信息的关键词 eg.&q=300路外环(十里河桥北-十里河桥西)&ct=北京市
 */
@property (nonatomic, readonly) NSString *searchString;

/** 
 *
 *  @brief 初始化MBBusLineResult对象
 *  @param dictionary 包含MBBusLineResult对象内容的数据字典
 *
 */
-(id)initWithDictionary:(NSDictionary *)dictionary;

@end

@interface MBBusLineDetailResult: NSObject {
@private
    NSDictionary *_internal;
    NSString *_instructions;
    NSUInteger _numPoints;
    NSArray *_path;
    NSArray *_stations;
}
/** @property   name
 *
 *  @brief  线路说明
 */
@property (nonatomic, readonly) NSString *instructions;

/** @property   numPoints
 *
 *  @brief  表示此公交线路的点的数量
 */
@property (nonatomic, readonly) NSUInteger numPoints;

/** @property   path
 *
 *  @brief  表示此公交线路的点的数组
 */
@property (nonatomic, readonly) NSArray *path;

/*
 *  MBBusStation对象的数组，每个BusStation之包含名称，坐标及searchString;
 */
/** @property   path
 *
 *  @brief MBBusStation对象的数组，每个BusStation只包含站点名称，坐标及对应searchString;
 */
@property (nonatomic, readonly) NSArray *stations;

/** 
 *
 *  @brief 初始化MBBusLineDetailResult对象
 *  @param dictionary 包含MBBusLineDetailResult对象内容的数据字典
 *
 */
-(id)initWithDictionary:(NSDictionary *)dictionary;

@end
