//
//  MBCircle.h
//  MBMapKit
//
//  Copyright 2011 Mapbar Inc. All rights reserved.
//

#import "MBShape.h"
#import "MBGeometry.h"
#import "MBOverlay.h"

/** @interface MBCircle
 *
 *  @brief
 *      MBCircle 类是一个具体的覆盖层对象，它用于在地图中展示一个圆形区域。本类管理定义这个区域的数据，同时在处理地图中的圆形
 *      绘制时它一般配合 MBCircleView 对象使用。
 */
@interface MBCircle : MBShape <MBOverlay> 
{
@package
    CLLocationCoordinate2D _coordinate;
    CLLocationDistance _radius;
    
    MBMapRect _boundingMapRect;
}

/**
 *
 *  @brief  使用指定的坐标和半径创建并返回 MBCircle 对象。
 *  @param  coord   圆形的中心点，由经度及维度值指定。
 *  @param  radius  圆形的半径，到中心点的距离（以米为单位计算）。
 *  @return 圆形覆盖层对象。
 */
+ (MBCircle *)circleWithCenterCoordinate:(CLLocationCoordinate2D)coord
                                  radius:(CLLocationDistance)radius;

/**
 *
 *  @brief  使用指定的矩形创建并返回 MBCircle 对象。
 *  @param  mapRect 决定圆形区域的地图矩形。矩形的中心点用作圆形的中心点。如果矩形不是正方形，矩形的长边用来决定圆形的半径。
 *  @return 圆形覆盖层对象。
 */
+ (MBCircle *)circleWithMapRect:(MBMapRect)mapRect;

/**
 *
 *  @brief  圆形区域的中心点，定义为经度和维度。 
 */
@property (nonatomic, readonly) CLLocationCoordinate2D coordinate;

/**
 *
 *  @brief  圆形区域的半径，以米为单位计算。
 */
@property (nonatomic, readonly) CLLocationDistance radius;

/**
 *
 *  @brief  圆形区域的边界矩形。
 *  @note
 *      当维度从赤道像极地移动时，地图点的物理距离逐渐变小。这就意味着需要更多的地图点来表示同样的距离。结果圆形覆盖层的边界
 *      矩形随着圆形中心点从赤道像极地移动而越来越大。
 */
@property (nonatomic, readonly) MBMapRect boundingMapRect; 

@end

