//
//  MBMultiPoint.h
//  MBMapKit
//
//  Copyright 2011 Mapbar Inc. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "MBShape.h"
#import "MBGeometry.h"

/** @interface MBMultiPoint
 *
 *  @brief
 *      MBMulitPoint是一个抽象超类，用于定义由许多点组成的形状。你不应该直接创建本类的实例。相反你应该创建 MBpolyline 
 *      或 MBPolygon 类的实例，你可以调用本类的方法和属性来获取与线条或多边形关联的指定点的信息。
 */
@interface MBMultiPoint : MBShape {
@package
    MBMapPoint *_points;
    NSUInteger _pointCount;
    
    MBMapRect _boundingRect;
}

/** @property   points
 *
 *  @brief  与形状关联的点数组。
 *  @note  
 *      数值中点的数量由 pointCount 属性指定。
 */
@property (nonatomic, readonly) MBMapPoint * points;

/** @property   pointCount
 *
 *  @brief  与形状关联的点数量。
 */
@property (nonatomic, readonly) NSUInteger pointCount;

/**
 *
 *  @brief  将一个或多个与形状关联的点转换为地图坐标值。
 *  @param  coords  输入时你必须提供足够大的C数值结构来容纳请求的坐标点数量。输出时，这个结构包含了请求的坐标数据。
 *  @param  range   你想要的点的范围。“location”元素表示你请求的第一个点，0表示其一个点，1表示第二个点，依此类推。
 *                   “length”元素表示你请求的点的数量。\e coords 中的数组必须足够大以容纳请求的坐标。
 *  @note
 *      本方法转换地图点到地图坐标再返回给你。如果你希望以地图点的类型获得每个点的值，你可以直接使用 points 属性。
 */
- (void)getCoordinates:(CLLocationCoordinate2D *)coords range:(NSRange)range;

@end

