//
//  MBPinAnnotationView.h
//  MBMapKit
//
//  Copyright 2011 Mapbar Inc. All rights reserved.
//

#import "MBAnnotationView.h"

enum 
{
    MBPinAnnotationColorRed = 0,    /**< 别针的头为红色。 红色别针表示地图中的终点。 */
    MBPinAnnotationColorGreen,      /**< 别针的头为绿色。 绿色别针表示地图中的起点。 */
    MBPinAnnotationColorPurple      /**< 别针的头为紫色。 绿色别针表示地图中的用户指定的点。 */
};
/** 别针标注支持的颜色*/
typedef NSUInteger MBPinAnnotationColor;

/** @interface MBPinAnnotationView
 *
 *  @brief  
 *      MBPinAnnotationView类提供一个具体的标注视图，在地图中现实一个别针图标。使用本类时，一可以设置别针的类型以及是否
 *      需要动画放置到地图中。
 */
@interface MBPinAnnotationView : MBAnnotationView
{
@private
    MBPinAnnotationColor _pinColor;
    CGPoint _originPosition;
    UITouch *_touch;
    UIImageView *_pinDownView;
    UIImageView *_pinFloatingView;
    UIImageView *_pinShadowView;
    NSString *_color;
    BOOL _animatesDrop;
}

/**
 *
 *  @brief  别针头的颜色。
 *  @note
 *      地图应用使用不同颜色的别针表示不同类型的地图标注。你自己的地图应用也应该一同样的方式来使用可用的别针颜色。，每种类型
 *      的使用说明参考常量 MBPinAnnotationColor 。
 */
@property (nonatomic) MBPinAnnotationColor pinColor;

/**
 *
 *  @brief   指示标注视图是否动画移入屏幕的布尔值。
 *  @note
 *      当本属性设为YES时，别针标注视图在地图视图中动画插到地图中的目标点。任何视图从屏幕外移到屏幕内时动画都会发生动画。
 */
@property (nonatomic) BOOL animatesDrop;

@end
