//
//  MBRoute.h
//  MBMapkit_library
//
//  Created by 张嘉伟 on 11-10-26.
//  Copyright 2011 Mapbar Inc. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreLocation/CoreLocation.h>

#import "MBGeometry.h"

/** @interface MBRoute
 *
 *  @brief
 *      MBRoute对象表示路线结果中存储单条路线的信息
 *     
 */
@interface MBRoute : NSObject {
@private
    NSDictionary *_internal;
}
/** @property   region
 *
 *  @brief  返回表示此路线范围。
 */
@property (nonatomic, readonly) MBCoordinateRegion region;

/** @property   distance
 *
 *  @brief  返回表示此路线总距离。
 *  @note   此属性可能未定义，因为距离可能未知。单位千米
 */
@property (nonatomic, readonly) double distance;

/** @property   duration
 *
 *  @brief  返回表示此路线总时间。
 *  @note   返回表示此路线总时间,此属性可能未定义，因为持续时间可能未知。
 */
@property (nonatomic, readonly) NSTimeInterval duration;//deprecate

/** @property   instructions
 *
 *  @brief  返回包含此路线的距离和时间概述
 */
@property (nonatomic, readonly) NSString *instructions;

/** @property   start
 *
 *  @brief  此路程的原点地址。
 */
@property (nonatomic, readonly) CLLocationCoordinate2D start;

/** @property   end
 *
 *  @brief  此路程的目标地址。
 */
@property (nonatomic, readonly) CLLocationCoordinate2D end;

/** @property   numSteps
 *
 *  @brief  返回此路线的路段数。
 */
@property (nonatomic, readonly) NSUInteger numSteps;

/** @property   steps
 *
 *  @brief  DirectionsStep 数组，其中每个路段都包含有关此路程中各个路段的信息。
 */
@property (nonatomic, readonly) NSArray *steps;

/** 
 *
 *  @brief 初始化MBRoute对象
 *  @param dictionary 包含MBRoute对象内容的数据字典
 *
 */
- (id)initWithDictionary:(NSDictionary *)dictionary;

@end