//
//  MBStep.h
//  MBMapkit_library
//
//  Created by 张嘉伟 on 11-10-26.
//  Copyright 2011 Mapbar Inc. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreLocation/CoreLocation.h>

/** @interface MBStep
 *
 *  @brief
 *      MBStep对象表示路线结果中存储一条路线中单个路段的信息
 *     
 */
@interface MBStep : NSObject {
@private
    NSDictionary *_internal;
}

/** @property   index
 *
 *  @brief  结果中可用的路线数目。
 *  @note   此路段的折线开始点的索引。
 */
@property (nonatomic, readonly) NSUInteger index;

/** @property   instructions
 *
 *  @brief  包含此路段描述的字符串。
 */
@property (nonatomic ,readonly) NSString *instructions;

/** @property   distance
 *
 *  @brief  表示此路段总距离，。
 *  @note   单位千米。
 */
@property (nonatomic, readonly) double distance;

/** @property   duration
 *
 *  @brief  表示此路段总时间。
 *  @note   此属性可能未定义，因为持续时间可能未知
 */
@property (nonatomic, readonly) NSTimeInterval duration;//deprecate

/** @property   start
 *
 *  @brief  此路段的起始位置。
 */
@property (nonatomic, readonly) CLLocationCoordinate2D start;

/** @property   end
 *
 *  @brief  此路段的结束位置。
 */
@property (nonatomic, readonly) CLLocationCoordinate2D end;

/** @property   numPoints
 *
 *  @brief  此路线的点数量。
 */
@property (nonatomic, readonly) NSUInteger numPoints;

/** @property   path
 *
 *  @brief  表示此路点的点数组。
 *  @note   CLLocationCoordiante(*100000)的序列，描述此路段的路程。
 */
@property (nonatomic, readonly) NSArray *path;

/** 
 *
 *  @brief 初始化MBStep对象
 *  @param dictionary 包含MBStep对象内容的数据字典
 *
 */
- (id)initWithDictionary:(NSDictionary *)dictionary;

@end