//
//  MBUserLocation.h
//  MBMapKit
//
//  Copyright 2011 Mapbar Inc. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "MBAnnotation.h"

@class CLLocation;
@class MBUserLocationInternal;

/** @interface MBUserLocation
 *
 *  @brief
 *      MBUserLocation类定义了一种特殊类型的标注用于表示用户当前位置。你不需要直接创建本类的实例。相反，你可以从地图视图中的 userLocation
 *      属性获取一个现有的MBUserLocation对象。
 */
@interface MBUserLocation : NSObject<MBAnnotation>
{
@private
    MBUserLocationInternal *_internal;
}

/** @property	updating
 *
 *  @brief  指示用户位置当前是否更新的布尔值。
 */
@property (readonly, nonatomic, getter=isUpdating) BOOL updating;

/** 
 *
 *  @brief  设备当前的位置。
 *  @note 
 *      如果地图视图当前未现实用户位置或者用户位置还未确定时本属性为nil。
 */
@property (readonly, nonatomic) CLLocation *location;

/** 用于显示用户位置标注的标题。 */
@property (retain, nonatomic) NSString *title;

/** 
 *
 *  @brief  用于显示用户位置标注的副标题。
 */
@property (retain, nonatomic) NSString *subtitle;

@end
